@@ -53,6 +53,11 @@ class Twig_SimpleTest
     }
 
     public function isDeprecated()
+    {
+        return (bool) $this->options['deprecated'];
+    }
+
+    public function getDeprecatedVersion()
     {
         return $this->options['deprecated'];
     }
